@@ -18,7 +18,7 @@ def get_file_id():
     pass
 
 
-def get_label_file_dict(self, use_session = True):
+def get_label_file_dict(self, schema_id = None, use_session = True):
     """
     Get Project label file id dict for project
 
@@ -42,11 +42,13 @@ def get_label_file_dict(self, use_session = True):
 
     endpoint = "/api/v1/project/" + self.project_string_id + \
                "/labels/view/name_to_file_id"
+    params = {'schema_id': schema_id}
     if use_session:
-        response = self.session.get(self.host + endpoint)
+        response = self.session.get(self.host + endpoint, params = params)
     else:
         # Add Auth
         response = requests.get(self.host + endpoint,
+                                params = params,
                                 headers = {'directory_id': str(self.directory_id)},
                                 auth = self.get_http_auth())
 
